@@ -21,12 +21,13 @@ use clap::{crate_authors, crate_version, App, AppSettings, Arg, ArgSettings};
 use csv::Error as CSVError;
 use csv::ErrorKind;
 use itertools::Itertools;
-use libradicl::cellfilter::{generate_permit_list, CellFilterMethod};
-use libradicl::schema::{ResolutionStrategy, SplicedAmbiguityModel};
 use mimalloc::MiMalloc;
 use rand::Rng;
 use slog::{crit, o, warn, Drain};
 
+use alevin_fry::cellfilter::{generate_permit_list, CellFilterMethod};
+use alevin_fry::quant::{ResolutionStrategy, SplicedAmbiguityModel};
+
 #[global_allocator]
 static GLOBAL: MiMalloc = MiMalloc;
 
@@ -166,6 +167,7 @@ fn main() {
     .arg(Arg::from("-e, --eq-labels=<eq-labels> 'file containing the gene labels of the equivalence classes'").takes_value(true).required(true))
     .arg(Arg::from("-o, --output-dir=<output-dir> 'output directory where quantification results will be written'").takes_value(true).required(true))
     .arg(Arg::from("-t, --threads 'number of threads to use for processing'").default_value(&max_num_threads))
+    .arg(Arg::from("--usa 'flag specifying that input equivalence classes were computed in USA mode'").takes_value(false).required(false))
     .arg(Arg::from("--quant-subset=<sfile> 'file containing list of barcodes to quantify, those not in this list will be ignored").required(false))
     .arg(Arg::from("--use-mtx 'flag for writing output matrix in matrix market instead of EDS'").takes_value(false).required(false));
 
@@ -216,7 +218,7 @@ fn main() {
     }
     */
 
-    if let Some(ref t) = opts.subcommand_matches("generate-permit-list") {
+    if let Some(t) = opts.subcommand_matches("generate-permit-list") {
         let input_dir: String = t.value_of_t("input").expect("no input directory specified");
         let output_dir: String = t
             .value_of_t("output-dir")
@@ -322,47 +324,47 @@ fn main() {
 
     // convert a BAM file, in *transcriptomic coordinates*, with
     // the appropriate barcode and umi tags, into a RAD file
-    if let Some(ref t) = opts.subcommand_matches("convert") {
+    if let Some(t) = opts.subcommand_matches("convert") {
         let input_file: String = t.value_of_t("bam").unwrap();
         let rad_file: String = t.value_of_t("output").unwrap();
         let num_threads: u32 = t.value_of_t("threads").unwrap();
-        libradicl::convert::bam2rad(input_file, rad_file, num_threads, &log)
+        alevin_fry::convert::bam2rad(input_file, rad_file, num_threads, &log)
     }
 
     // convert a rad file to a textual representation and write to stdout
-    if let Some(ref t) = opts.subcommand_matches("view") {
+    if let Some(t) = opts.subcommand_matches("view") {
         let rad_file: String = t.value_of_t("rad").unwrap();
         let print_header = t.is_present("header");
         let mut out_file: String = String::from("");
         if t.is_present("output") {
             out_file = t.value_of_t("output").unwrap();
         }
-        libradicl::convert::view(rad_file, print_header, out_file, &log)
+        alevin_fry::convert::view(rad_file, print_header, out_file, &log)
     }
 
     // collate a rad file to group together all records corresponding
     // to the same corrected barcode.
-    if let Some(ref t) = opts.subcommand_matches("collate") {
+    if let Some(t) = opts.subcommand_matches("collate") {
         let input_dir: String = t.value_of_t("input-dir").unwrap();
         let rad_dir: String = t.value_of_t("rad-dir").unwrap();
         let num_threads = t.value_of_t("threads").unwrap();
         let compress_out = t.is_present("compress");
         let max_records: u32 = t.value_of_t("max-records").unwrap();
-        libradicl::collate::collate(
+        alevin_fry::collate::collate(
             input_dir,
             rad_dir,
             num_threads,
             max_records,
             compress_out,
             &cmdline,
-            &VERSION,
+            VERSION,
             &log,
         )
         .expect("could not collate.");
     }
 
     // perform quantification of a collated rad file.
-    if let Some(ref t) = opts.subcommand_matches("quant") {
+    if let Some(t) = opts.subcommand_matches("quant") {
         let num_threads = t.value_of_t("threads").unwrap();
         let num_bootstraps = t.value_of_t("num-bootstraps").unwrap();
         let init_uniform = t.is_present("init-uniform");
@@ -410,9 +412,9 @@ fn main() {
         // if the input directory contains the valid json file we want
         // then proceed.  otherwise print a critical error.
         if json_path.exists() {
-            let velo_mode = libradicl::utils::is_velo_mode(input_dir.to_string());
+            let velo_mode = alevin_fry::utils::is_velo_mode(input_dir.to_string());
             if velo_mode {
-                match libradicl::quant::velo_quantify(
+                match alevin_fry::quant::velo_quantify(
                     input_dir,
                     tg_map,
                     output_dir,
@@ -427,7 +429,7 @@ fn main() {
                     small_thresh,
                     filter_list,
                     &cmdline,
-                    &VERSION,
+                    VERSION,
                     &log,
                 ) {
                     // if we're all good; then great!
@@ -452,7 +454,7 @@ fn main() {
                     },
                 }; // end match if
             } else {
-                match libradicl::quant::quantify(
+                match alevin_fry::quant::quantify(
                     input_dir,
                     tg_map,
                     output_dir,
@@ -467,7 +469,7 @@ fn main() {
                     small_thresh,
                     filter_list,
                     &cmdline,
-                    &VERSION,
+                    VERSION,
                     &log,
                 ) {
                     // if we're all good; then great!
@@ -501,21 +503,23 @@ fn main() {
 
     // Given an input of equivalence class counts, perform inference
     // and output a target-by-cell count matrix.
-    if let Some(ref t) = opts.subcommand_matches("infer") {
+    if let Some(t) = opts.subcommand_matches("infer") {
         let num_threads = t.value_of_t("threads").unwrap();
         let use_mtx = t.is_present("use-mtx");
         let output_dir = t.value_of_t("output-dir").unwrap();
         let count_mat = t.value_of_t("count-mat").unwrap();
         let eq_label_file = t.value_of_t("eq-labels").unwrap();
         let filter_list = t.value_of("quant-subset");
+        let usa_mode = t.is_present("usa");
         //let bc_file = t.value_of_t("barcodes").unwrap();
 
-        libradicl::infer::infer(
+        alevin_fry::infer::infer(
             //num_bootstraps,
             //init_uniform,
             //summary_stat,
             count_mat,
             eq_label_file,
+            usa_mode,
             //bc_file,
             use_mtx,
             num_threads,
